@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2023 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2021 Oracle and/or its affiliates. All rights reserved.
  *
  * This program and the accompanying materials are made available under the
  * terms of the Eclipse Distribution License v. 1.0, which is available at
@@ -13,8 +13,8 @@
  */
 module org.glassfish.jaxb.jxc {
 
-    requires transitive java.xml.bind;
-    requires transitive java.compiler;
+    requires transitive jakarta.xml.bind;
+    requires java.compiler;
     requires jdk.compiler;
     requires java.logging;
     requires transitive org.glassfish.jaxb.runtime;
