@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005, 2021 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2022 Oracle and/or its affiliates. All rights reserved.
  *
  * This program and the accompanying materials are made available under the
  * terms of the Eclipse Distribution License v. 1.0, which is available at
@@ -19,8 +19,11 @@ import org.xml.sax.SAXParseException;
  * @author Kohsuke Kawaguchi (kohsuke.kawaguchi@sun.com)
  */
 public interface ErrorListener extends ErrorHandler {
-    abstract void error (SAXParseException exception);
-    abstract void fatalError (SAXParseException exception);
-    abstract void warning (SAXParseException exception);
+    @Override
+    void error(SAXParseException exception);
+    @Override
+    void fatalError(SAXParseException exception);
+    @Override
+    void warning(SAXParseException exception);
 
 }
